@@ -52,7 +52,7 @@ def get_operator(self,name,**kwargs):
       elif name=="mz":
         return self.get_operator("sz")@self.get_operator("electron")
       elif name=="layer": return operators.get_layer(self,**kwargs)
-      elif name=="valley":  return operators.get_valley(self)
+      elif name=="valley":  return operators.get_valley(self,**kwargs)
       elif name=="valley_x":  return operators.get_valley_taux(self)
       elif name=="inplane_valley": return operators.get_inplane_valley(self)
       elif name=="valley_upper" or name=="valley_top":
